from datetime import datetime
from django.utils.html import format_html


# 自定义日期格式: 年-月-日 时:分:秒
def custom_date_format(self, obj):
    try:
        return format_html(
            '<span style="color: black;">{}</span>',
            obj.strftime('%Y-%m-%d %H:%M:%S'))
    except:
        pass
    return obj

# 当前日期和时间
def current_time():
    dt=datetime.now()
    return  datetime.strftime(dt,'%Y-%m-%d %H:%M:%S')


# 自定义日期格式: 年-月-日 时:分:秒
def date_html(self, date):
    try:
        return format_html(
            '<span style="color: black;">{}</span>',
            date.strftime('%Y-%m-%d %H:%M:%S'))
    except:
        pass
    return date

# 当前日期和时间
def current_str():
    dt=datetime.now()
    return  datetime.strftime(dt,'%Y-%m-%d %H:%M:%S')


# -*- encoding: utf-8 -*-
"""
@文件名:   base_model.py   
@版权:     (C)Copyright 山西博维创 2022-2024

@创建时间              @作者       @版本        @说明
---------------      -------    --------    -----------
2022/10/5 12:39      戎伟峰       1.0         None
"""
import uuid

import mptt.models
from django.contrib.auth.models import User
from django.db import models



class BaseModel(models.Model):
    """
    普通模型基类
    定义系统字段:
        id: id
        name:名称
        note:备注
        create_time:创建时间
        modify_time:修改时间
        state: 状态
    基类中不能使用引用字段
    """
    id = models.BigAutoField(verbose_name='ID', primary_key=True)
    name = models.CharField(verbose_name='名称', max_length=200, )  # unique=True
    code = models.CharField(verbose_name='编码', max_length=200, null=True,blank=True)
    note = models.TextField(verbose_name='备注', max_length=500, null=True, blank=True)
    create_time = models.DateTimeField(verbose_name='创建时间', auto_now_add=True)
    modify_time = models.DateTimeField(verbose_name='创建时间', auto_now=True)
    creator=models.ForeignKey(User,db_column='creator',verbose_name='创建人',related_name='%(app_label)s_%(class)s_creator_user',on_delete=models.CASCADE,null=True)
    modifier=models.ForeignKey(User,db_column='modifier',verbose_name='修改人',related_name='%(app_label)s_%(class)s_modify_user',on_delete=models.CASCADE,null=True)
    STATE=(
        (0,'禁用'),
        (1,'启用')
    )
    state=models.SmallIntegerField(verbose_name='状态',choices=STATE,default=1)
    order_no =models.BigIntegerField(verbose_name='序号',default=1)

    class Meta:
        abstract=True  #  抽象类

    def __str__(self):
        return self.name



class BaseTreeModel(mptt.models.MPTTModel,BaseModel):
    """
    树形模型基类
    """

    parent = models.ForeignKey('self', verbose_name='上级', null=True, blank=True, on_delete=models.SET_NULL,related_name='parent_'+ '%(app_label)s_%(class)s') # relate_name_prefix()

    class Meta:
        abstract = True

    class MPTTMeat:
        parent_attr = 'parent'







# -*- encoding: utf-8 -*-
"""
@文件名:   pycharts_util.py
@版权:     (C)Copyright 山西博维创 2022-2024

@创建时间              @作者       @版本        @说明
---------------      -------    --------    -----------
2022/10/21 0:39      戎伟峰       1.0         pyechart-折线
"""
import pyecharts.options as opts
from pyecharts.charts import Line, Pie
from pyecharts.globals import ThemeType


def line(x,y,title='') :
    """
       折线
       :param x:
       :param y:
       :return:
    """
    c = (
        Line()
            .add_xaxis(xaxis_data=x)
            .add_yaxis(
                series_name='', # title
                y_axis=y,
                is_connect_nones=True)
            .set_global_opts(title_opts=opts.TitleOpts(title='')) # title
            .dump_options_with_quotes()
    )
    return c


def pie(x,y,title='') :
    """
       饼图
       :param x:
       :param y:
       :return:
    """
    c = (
        Pie(init_opts=opts.InitOpts(theme=ThemeType.DARK))
            # 为饼图增加标签和数据
            .add("", list(zip(x, y)))
            # 为饼图增加主标题和副标题
            .set_global_opts(title_opts=opts.TitleOpts(title=title, subtitle=""))
            # 为饼图增加数据标签
            .set_series_opts(label_opts=opts.LabelOpts(formatter="{b}: {c}\n({d}%)"))
            .dump_options_with_quotes()
    )



    return c


# -*- encoding: utf-8 -*-
"""
@文件名:   export_util.py   
@版权:     (C)Copyright 山西校安通 2022-2024

@创建时间              @作者       @版本        @说明
---------------      -------    --------    -----------
2022/10/6 18:14      戎伟峰       1.0         None
"""

import logging
from datetime import datetime


logger = logging.getLogger(__name__)

# 导出excel名称
def export_filename(self):
    """
    导出文件名称定义
    模型verbose_name + 导出日期
    基于 import_export 组件
    :param self:
    :param request:
    :return:
    """
    import urllib.parse
    date_str = datetime.now().strftime('%Y-%m-%d')
    filename_diy = urllib.parse.quote(self.model._meta.verbose_name)
    filename = "%s_%s.%s" % (filename_diy, date_str, 'xls') # file_format.get_extension()
    return filename



# -*- encoding: utf-8 -*-

"""
@文件名称:    random_util.py 
@版   权:    (C)Copyright 山西博维创 2023
@创建时间:    2023/2/21 21:03 
@作   者:    rongweifeng     	
@版   本:    1.0   	            	
@说   明:
  随机数生成器
"""

import random

def generate_vcode(length=6):
    """
    生成随机验证码
    :param length: 验证码长度,默认6位
    :return:
    """
    return ''.join(random.choices('0123456789',k=length))





# -*- encoding: utf-8 -*-

"""
@文件名称:    permission_util.py 
@版   权:    (C)Copyright 山西博维创 2023
@创建时间:    2023/2/20 15:18 
@作   者:    rongweifeng     	
@版   本:    1.0   	            	
@说   明:
  django权限
"""
import logging

logger =logging.getLogger(__name__)

def get_groups(request):
    """
    获取用户隶属的组名
    :param request:
    :return:
    """
    group_names=[]
    try:
        for group in request.user.groups.all():
            group_names.append(group.name)
    except:
        logger.log('用户未登录')

    return group_names


# -*- encoding: utf-8 -*-

"""
@文件名称:    sms_util.py 
@版   权:    (C)Copyright 山西博维创 2023
@创建时间:    2023/2/21 20:42 
@作   者:    rongweifeng     	
@版   本:    1.0   	            	
@说   明:
  短信服务类
"""
import json
import logging

from aliyunsdkcore.client import AcsClient
from aliyunsdkcore.request import CommonRequest

import settings.base
from utils.tools import random_util

logger=logging.getLogger(__name__)

def send_phone_code(phone):
    """
    发送手机验证码
    :param phone: 接收手机号码,多个号码用逗号分隔
    :return: 返回验证码
    """
    vcode=random_util.generate_vcode(6)
    template=settings.base.SMS_TEMPLATE_VCODE
    params={
        "code":vcode,
    }
    if send_phone(phone,template,params):
        return vcode
    return ''


def send_phone(phone,template,params):
    """
    发送手机短信
    :param phone: 接收手机号码,多个号码用逗号分隔
    :param message: 短信内容
    :return: 返回true/false
    """

    # 创建客户端对象
    client = AcsClient(settings.base.SMS_APP_ID, settings.base.SMS_APP_KEY)
    # 设置发送请求
    request = CommonRequest()
    request.set_accept_format('json')
    request.set_domain('dysmsapi.aliyuncs.com') # 阿里云短信网关
    request.set_method('POST')
    request.set_protocol_type('https')  # http协议
    request.set_version('2017-05-25')
    request.set_action_name('SendSms')
    request.add_query_param('RegionId', "cn-hangzhou")
    request.add_query_param('PhoneNumbers', phone)
    request.add_query_param('SignName', settings.base.SMS_SIGN)   # 短信签名
    request.add_query_param('TemplateCode', template)      # 短信模板
    request.add_query_param('TemplateParam', params)    # 模板参数
    message ={
        "template":template,
        "params":params,
        "phone":phone,
    }
    try:
        response = client.do_action_with_exception(request)
        ret = json.loads(response.decode())
        if ret.get('Code') == "OK":
            logger.info('短信发送成功,发送内容:{}'.format(message))
            return True
        else:
            logger.error('短信发送失败,发送内容:{}'.format(message))
    except Exception as e:
        logger.error('短信发送失败,发送内容:{},错误原因:{}'.format(message,e))

    return False





# -*- encoding: utf-8 -*-
"""
@文件名:   jsonresponse_util.py
@版权:     (C)Copyright 山西博维创 2022-2024

@创建时间              @作者       @版本        @说明
---------------      -------    --------    -----------
2022/10/21 0:38      戎伟峰       1.0         json响应
"""
import json

from django.http import HttpResponse


def response_as_json(data):
    json_str = json.dumps(data)
    response = HttpResponse(
        json_str,
        content_type="application/json",
    )
    response["Access-Control-Allow-Origin"] = "*"
    return response


def json_response(data, code=200):
    data = {
        "code": code,
        "msg": "success",
        "data": data,
    }
    return response_as_json(data)


def json_error(error_string="error", code=500, **kwargs):
    data = {
        "code": code,
        "msg": error_string,
        "data": {}
    }
    data.update(kwargs)
    return response_as_json(data)


JsonResponse = json_response
JsonError = json_error


# -*- encoding: utf-8 -*-
"""
@文件名:   base_import_admin.py   
@版权:     (C)Copyright 山西博维创 2022-2024

@创建时间              @作者            @版本           @说明
---------------      -----------    --------       -----------
2022/11/24 11:26      rongweifeng       1.0           导入导出基类-基于import-export
"""
from import_export.admin import ImportExportMixin
from import_export.formats import base_formats

from utils.base.base_admin import BaseAdmin
from utils.base.base_export_resource import BaseExportResource
from utils.tools import export_util


class BaseImportAdmin(ImportExportMixin,BaseAdmin):
    """
    导入导出基类
    包含导入和导出
    基于import-export组件
    """
    resource_class = BaseExportResource


    def get_export_filename(self, request, queryset, file_format):
        return export_util.export_filename(self)

    def get_import_formats(self):
        formats = (
            base_formats.XLS,
        )
        return [f for f in formats if f().can_export()]


    def get_export_formats(self):
        """
        重写方法
        限制导出文件格式
        :return:
        """
        formats = (
            base_formats.XLS,
        )
        return [f for f in formats if f().can_export()]

    def has_import_permission(self, request):
        """
        导入按钮控制
        :param request:
        :return:
        """
        if request.user.is_superuser:
            return True
        elif '{0}_import'.format(self.get_app_class_name(request)) in request.user.get_all_permissions():
            return True
        return False

    def has_export_permission(self, request):
        """
        导出按钮控制
        :param request:
        :return:
        """
        if request.user.is_superuser:
            return True
        elif '{0}_export'.format(self.get_app_class_name(request)) in request.user.get_all_permissions():
            return True
        return False


    def get_app_class_name(self,request):
        """
        获取包含app_labe的类名称
        :param request:
        :return:
        """
        name= '{0}.{1}'.format(self.model._meta.app_label,self.model._meta.model_name)
        return name


# -*- encoding: utf-8 -*-
"""
@文件名:   base_export_admin.py
@版权:     (C)Copyright 山西博维创 2022-2024

@创建时间              @作者       @版本        @说明
---------------      -------    --------    -----------
2022/10/6 17:15      戎伟峰       1.0         导出基类-基于import-export
"""
from import_export.admin import ExportMixin
from import_export.formats import base_formats

from utils.base.base_admin import BaseAdmin
from utils.tools import export_util


class BaseExportAdmin(ExportMixin,BaseAdmin):
    """
    导出基类
    只有导出
    基于import-export组件
    """
    def get_export_filename(self, request, queryset, file_format):
        """
         impot-export方法重写
        :param request:
        :param queryset:
        :param file_format:
        :return:
        """
        return export_util.export_filename(self)

    def get_export_formats(self):
        """
        重写方法
        限制导出文件格式
        :return:
        """
        formats = (
            base_formats.XLS,
        )
        return [f for f in formats if f().can_export()]

    def has_export_permission(self, request):
        return True

    def has_import_permission(self, request):
        """
        重写方法
        允许导出按钮
        禁止导入按钮
        :param request:
        :return:
        """
        return False






# -*- encoding: utf-8 -*-
"""
@文件名:   base_admin.py
@版权:     (C)Copyright 山西博维创 2022-2024

@创建时间              @作者       @版本        @说明
---------------      -------    --------    -----------
2022/10/5 13:28      戎伟峰       1.0         管理类-基类
"""
from django.contrib import admin

from utils.tools import md5_util
from utils.tools.pinyin_util import hanzi_to_pinyin_first


class BaseAdmin(admin.ModelAdmin):
    list_display = ['name','note','state','creator','create_time','modifier','modify_time']
    exclude = ['id',  'code','create_time', 'creator', 'modify_time', 'modifier', ]  # 编辑页-系统项
    ordering = ['id',] # 排序
    list_per_page = 30  # 每页显示条数
    list_max_show_all = 500  # 显示全部

    def save_model(self, request, obj, form, change):
        """
        重写保存方法
        给系统字段赋值
        :param request:
        :param obj:
        :param form:
        :param change: 对象编辑状态
        :return:
        """
        # 检查系统字段是否存在
        if hasattr(obj,'creator') and hasattr(obj,'create_time') and hasattr(obj,'modify_time') and hasattr(obj,'modifier'):
            if change: # 修改状态
                if not obj.creator:
                    obj.creator = request.user
                obj.modifier = request.user
            else: # 添加状态
                obj.creator = request.user
                obj.modifier = request.user
        # 生成编码
        if not obj.code:
            obj.code=self.generate_code(obj)
        # 自动生成序号
        if hasattr(obj,'order_no'):
            if not change:
                obj.order_no=self.generate_order_no(obj)

        # 密码加密存储
        if hasattr(obj,'password') and not change:
           obj.password=self.password_md5(obj)
        return super().save_model(self, obj, form, change)


    def generate_code(self,obj):
        """
        自动生成编码
        根据名称生成拼音首字母
        :param obj:
        :return:
        """
        if not obj:
            return ''
        if not obj.name or obj.name=='':
            return ''
        code=''
        try:
            code=hanzi_to_pinyin_first(self,obj.name)
        except:
            pass
        return code

    def generate_order_no(self,obj):
        """
        生成序号
        :param obj:
        :return:
        """
        if not obj:
            return 1
        order_no = 1
        if hasattr(obj, 'parent'):  # 根据父级计算
            try:
                order_no = self.model.objects.filter(parent=obj.parent).order_by('-order_no').first().order_no + 1
            except:
                pass
        else: # 根据同级计算
            try:
                order_no = self.model.objects.all().order_by('-order_no').first().order_no + 1
            except:
                pass
        return order_no


    def password_md5(self,obj):
        """
        密码使用md5保存
        只针对新建数据
        编辑状态保存由子类自己实现
        :param self:
        :param obj:
        :return:
        """

        if not obj:
            return ''
        password = obj.password
        try:
            password = md5_util.md5_password(obj.password)
        except:
            pass
        return password


# -*- encoding: utf-8 -*-

"""
@文件名称:    mail_util.py 
@版   权:    (C)Copyright 山西博维创 2023
@创建时间:    2023/2/21 20:41 
@作   者:    rongweifeng     	
@版   本:    1.0   	            	
@说   明:
  email工具类
  1.发送附件暂时没有实现
"""
import logging
import smtplib
from email.header import Header
from email.mime.text import MIMEText
from email.utils import parseaddr,formataddr

import settings
from utils.tools import random_util

logger=logging.getLogger(__name__)



def send_mail_vcode(to_address):
    """
    发送验证码到邮箱
    :param to_address: 接收邮箱
    :return: 返回验证码
    """
    vcode=random_util.generate_vcode(6)
    message = "您好,欢迎注册,您的验证码:{},有效期60分钟,请立即验证".format(vcode)
    if send_mail(message,to_address):
        return vcode
    return ''

def send_mail(message,to_addr):
    """
    发送邮件
    :param to_addr:     接收方邮箱,支持多个, 用;进行连接
    :return:            返回true和false
    """
    # 构建smtp对象
    server =smtplib.SMTP(settings.base.MAIL_SMTP_SERVER,25)
    # 设置调试级别
    server.set_debuglevel(1)
    try:
        # 登录邮箱
        server.login(settings.base.MAIL_SEND_EMAIL_ADDR, settings.base.MAIL_SEND_EMAIL_PASSWORD)
        # 生成邮件内容
        msg = generate_mail_message(message, settings.base.MAIL_SEND_EMAIL_ADDR, to_addr)
        # 发送邮件
        server.sendmail(settings.base.MAIL_SEND_EMAIL_ADDR, to_addr.split(';'), msg.as_string())
        # 退出邮件服务器
        server.quit()
    except Exception as e:
        logger.error('邮件发送失败:{},错误原因:{}'.format(msg.as_string(),e))
        return False
    logger.info('邮件发送成功'.format(msg.as_string()))
    return True




def generate_mail_message(message,from_addr,to_addr):
    """
    生成邮件内容
    :param vcode:验证码
    :param from_addr:发送邮箱
    :param to_addr:接收邮箱
    :return:包含验证码的邮件内容
    """
    msg=MIMEText(message,'plain','utf-8')
    msg['From']=_format_addr('山西博维创<{}>'.format(from_addr))
    msg['To']=_format_addr('验证码<{}>'.format(to_addr))
    msg['Subject']=Header('邮箱验证码').encode()
    return msg



def _format_addr(s):
    """
    格式化邮件头
    :param s: 原始内容
    :return: 格式化后的内容
    """
    name,addr =parseaddr(s)
    return formataddr((Header(name,'utf-8').encode(),addr))






# -*- encoding: utf-8 -*-

"""
@文件名称:    setup.py 
@版   权:    (C)Copyright 山西博维创 2023
@创建时间:    2023/2/22 02:46 
@作   者:    rongweifeng     	
@版   本:    1.0   	            	
@说   明:
  
"""
from setuptools import setup, find_packages

setup(
    name='sxbwc_toolbox',
    version='0.0.1',
    author='sxbwc',
    author_email='65489942@qq.com',
    description='山西博维创python工具包',
    url='http://www.sxbwc.cn',
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    py_modules=[
        'sxbwc_toolbox.base.base_admin',
        'sxbwc_toolbox.base.base_export_admin',
        'sxbwc_toolbox.base.base_import_admin',
        'sxbwc_toolbox.base.base_export_resource',
        'sxbwc_toolbox.base.base_model',
        'sxbwc_toolbox.tools.datetime_util',
        'sxbwc_toolbox.tools.export_util',
        'sxbwc_toolbox.tools.jsonresponse_util',
        'sxbwc_toolbox.tools.mail_util',
        'sxbwc_toolbox.tools.md5_util',
        'sxbwc_toolbox.tools.message_util',
        'sxbwc_toolbox.tools.permission_util',
        'sxbwc_toolbox.tools.pinyin_util',
        'sxbwc_toolbox.tools.pycharts_util',
        'sxbwc_toolbox.tools.random_util',
        'sxbwc_toolbox.tools.datetime_util',
        'sxbwc_toolbox.tools.sms_util',
        'sxbwc_toolbox.tools.weixin_template_util',

    ]
)



# -*- encoding: utf-8 -*-
"""
@文件名:   pinyin_util.py   
@版权:     (C)Copyright 山西校安通 2022-2024

@创建时间              @作者       @版本        @说明
---------------      -------    --------    -----------
2022/10/6 11:33      戎伟峰       1.0         拼音工具类
"""
from xpinyin import Pinyin

def hanzi_to_pinyin_first(self,str):
    """
    汉字转拼音首字母
    :param self:
    :param str:
    :return:
    """
    p = Pinyin()
    return p.get_initial(str,'')


def hanzi_to_pinyin(self,str):
    """
    汉字转拼音全拼
    :param self:
    :param str:
    :return:
    """
    p = Pinyin()
    return p.get_pinyin(str, '')




# -*- encoding: utf-8 -*-

"""
@文件名称:    message_util.py 
@版   权:    (C)Copyright 山西博维创 2023
@创建时间:    2023/2/20 22:44 
@作   者:    rongweifeng     	
@版   本:    1.0   	            	
@说   明:
  消息工具类
"""
import json
import logging

import requests
from dingtalkchatbot.chatbot import DingtalkChatbot
import settings.dev
from utils.tools import weixin_template_util

logger=logging.getLogger(__name__)

def send_dingtalk_message(message, mobiles=[]):
    """
    发送钉钉文本消息
    :param message:
    :param mobiles:
    :return:
    """
    webhook=settings.base.DING_TALK_WEBHOOK
    secret=settings.base.DING_TALK_SECRET

    # 机器人初始化
    # :param webhook: 钉钉群自定义机器人webhook地址
    #  :param secret: 机器人安全设置页面勾选“加签”时需要传入的密钥
    #  :param pc_slide: 消息链接打开方式，默认False为浏览器打开，设置为True时为PC端侧边栏打开
    #  :param fail_notice: 消息发送失败提醒，默认为False不提醒，开发者可以根据返回的消息发送结果自行判断和处理
    xiaoding = DingtalkChatbot(webhook=webhook, secret=secret)

    # 发送消息
    # :param msg: 消息内容
    #  :param is_at_all: @所有人时：true，否则为false（可选）
    #  :param at_mobiles: 被@人的手机号（注意：可以在msg内容里自定义@手机号的位置，也支持同时@多个手机号，可选）
    # :param at_dingtalk_ids: 被@人的dingtalkId（可选）
    # :param is_auto_at: 是否自动在msg内容末尾添加@手机号，默认自动添加，可设置为False取消（可选）

    if isinstance(mobiles,str):
        mobiles=[mobiles]
    try:
        if mobiles is None or len(mobiles)==0:
            xiaoding.send_text(msg=message, is_at_all=True, at_mobiles=[])
            logger.info('发送钉钉消息成功,消息内容:{},通知所有人'.format(message))
        else:
            xiaoding.send_text(msg=message,at_mobiles=mobiles)
            logger.info('发送钉钉消息成功,消息内容:{},通知人员:{}'.format(message,';'.join(mobiles)))
    except Exception as e :
        logger.error('发送钉钉消息失败,消息内容:{},通知人员:{},错误信息:{}'.format(message,';'.join(mobiles),e))


def send_weixin_message(message,mobiles,picture=None):
    """
    发送企业微信消息
    :param message:
    :param mobiles:
    :param picture:  图片对象
        {
            "url": "点击图片的跳转地址",
            "image":"图片的地址"
        }
    :return:
    """
    webhook = settings.base.WEIXIN_TALK_WEB_HOOK
    data={}
    if picture: # 图文消息
        data = {
            "msgtype": "news",  # news格式消息
            "news": {
                "articles": [
                    {
                        "title": message,  # 主标题
                        "description": message,  # 副标题
                        "url": picture.get('url'),  # 这段是图文消息点进去后转到的地址
                        "picurl": picture.get('image') # 图片地址
                    }
                ]
            }
        }
    else: # 文本消息
        data = {
            "msgtype": "text",
            "text": {
                "content": message,
                "mentioned_list": [],
            }
    }
    try:
        res = requests.post(url=webhook, json=data)
        ret= json.loads(res.text)
        if ret.get('errcode')==0:
            logger.info('发送企业微信消息成功,消息内容:{}'.format(message))
        else:
            logger.error('发送企业微信消息失败,消息内容:{},错误信息:{}'.format(message,ret.text.get('errmsg')))
    except Exception as e :
        logger.error('发送企业微信消息失败,消息内容:{},错误信息:{}'.format(message,e))



def send_weixin_template_message(openids,template,params,link=''):
    """
    发送微信模板消息
    :param openids: openid集合
        1个:字符串
        多个:列表
    :param template:
        模板消息id
    :param params:
        模板参数,格式:
            "参数名1:
            {
                "value":"参数值",
                "color": "#173177"
            },
            "参数名2:
            {
                "value":"参数值"
            }
    :param link: 链接地址
    :return:
    """
    if isinstance(openids,str) :
        openids =[openids]
    if len(openids)==0:
        return
    for openid in openids:
        try:
            message={
                'openid':openid,
                'template':template,
                'params':params
            }
            ret =weixin_template_util.send_msg(openid,template,params,link)
            if ret:
                logger.info('发送微信模板消息成功,消息内容:{}'.format(message))
            else:
                logger.error('发送微信模板消息失败,消息内容:{}'.format(message))

        except Exception as e :
            logger.error('发送微信模板消息失败,消息内容:{},错误信息{}'.format(message,e))


"""  测试数据  =====================================
    openids="o6tb45oT_lVwYo0ryqNUPGbGqNIQ"
    template="xMOLkofOdeJmpEhbXXWK1TxUym5JEACOkxw6hzf-ex4"
    params={
        "first":{
            "value":"访问申请"
        },
        "keyword1":{
            "value":"戎伟峰",
        },
        "keyword2":{
            "value":"找周晓旭签合同"
        },
        "keyword3": {
            "value":"2023-2-22 16:00"
        },

        "keyword4": {
            "value":"13835165255",
        },
        "remark":{
            "value":"已经电话预约"
        }
    }
"""

if __name__ == '__main__':
    message="明天准备下井"
    # picture={
    #     "url":'https://www.baidu.com',
    #     "image":"https://t7.baidu.com/it/u=1819248061,230866778&fm=193&f=GIF"
    # }
    # send_weixin_message(message,'13835165255',picture)
    send_dingtalk_message(message,'13835165255')


# -*- encoding: utf-8 -*-
"""
@文件名:   base_export_resource.py
@版权:     (C)Copyright 山西博维创 2022-2024

@创建时间              @作者       @版本        @说明
---------------      -------    --------    -----------
2022/10/6 17:23      戎伟峰       1.0         import_export 资源基类
"""
import tablib
from import_export.resources import ModelResource

from utils.base.base_model import BaseModel


class BaseExportResource(ModelResource):
    class Meta:
        model = BaseModel
        fields = '__all__'  # 指定导出的字段
        export_order = ()  # 指定导出的顺序
        exclude = ('creator', 'create_time', 'modifier', 'modify_time', 'order_no', 'state', 'order_no')  # 不用导出的内容
        import_id_fields = ('id',)  # 指定ID字段名称

    def __init__(self):
        """
        初始化数据
        生成verbose_name数据集
        """
        super().__init__()
        field_list = self.fields
        self.vname_dict = {}
        for item in field_list.keys():
            self.vname_dict[item] = getattr(self.Meta.model, item).field.verbose_name  # field_list[item].verbose_name

    def get_export_fields(self):
        """
        重写方法
        转换导出字段
        处理表头,显示verbose_name(中文)
        :return:
        """
        fields = self.get_fields()
        for i, field in enumerate(fields):
            field_name = self.get_field_name(field)
            if field_name.find("__") > 0:
                _field_name = field_name.split("__")[0]
                if _field_name in self.vname_dict.keys():
                    field.column_name = self.vname_dict[_field_name]
            elif field_name in self.vname_dict.keys():
                field.column_name = self.vname_dict[field_name]
        return fields

    def get_sheet_name(self):
        """
        获取sheet页的中文名称
        修改sheet页名称为模型的verbose_name
        ??? 未实现,调用方法未知
        :return:
        """
        name = '导出数据'
        try:
            name = self.Meta.model._meta.verbose_name
            # data = tablib.Dataset(headers=headers, title="Sheet")
        except:
            pass

        return name



# -*- encoding: utf-8 -*-
"""
@文件名:   md5.py
@版权:     (C)Copyright 山西校安通 2022-2024

@创建时间              @作者       @版本        @说明
---------------      -------    --------    -----------
2022/8/26 17:28      戎伟峰       1.0        md5-加解密
"""
import hashlib

def md5_password(password):
    """
    md5加密密码
    :param password:  密码明文
    :return: 加密后的值
    """
    try:
        md5_password = hashlib.md5(bytes(password, encoding='utf-8')).hexdigest()
    except:
        md5_password = ''
    return md5_password


# -*- encoding: utf-8 -*-

"""
@文件名称:    weixin_template_util.py
@版   权:    (C)Copyright 山西博维创 2023
@创建时间:    2023/2/22 01:13 
@作   者:    rongweifeng     	
@版   本:    1.0   	            	
@说   明:
  微信公众号工具箱
"""
import json
import time
import requests
import settings.base

exp_time = 0
access_token = ''

def get_access_token():
    """
    获取access_token
    :return: 返回token
    """
    global exp_time, access_token
    appid = settings.base.WEIXIN_TEMPLATE_APPID
    appkey = settings.base.WEIXIN_TEMPLATE_APPKEY
    if time.time() > exp_time:
        try:
            res= requests.get(
                'https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid={}&secret={}'.format(appid,appkey))
            data = json.loads(res.text)
            access_token = data['access_token']
            exp_time = time.time() + data['expires_in'] - 10  # 减一点防止快到时间的时候已经失效了
        except Exception as e:
            raise e
    return access_token


def send_msg(openid,template,params,link=''):
    """
    发送单条模板消息
    :param openid: openid
    :param template: 模板消息id
    :param params: 模板参数
    :link: 点击链接地址
    :return:
    """

    url = 'https://api.weixin.qq.com/cgi-bin/message/template/send?access_token=' + get_access_token()
    data = {
        "touser": openid,
        "template_id": template,
        "url": link,
        "data": params,

    }

    try:
        res = requests.post(url, json.dumps(data))
        ret=json.loads(res.text)
        if ret.get('errcode')==0:
            return True
    except Exception as e:
        raise e
    return False


